<?php
/**
 * Plugin Name: EP TecDoc
 * Description: TecDoc integracija.
 * Version: 1.2.0
 * Author: Elektronika Perhoč
 * Author URI: https://ep.hr
 */

define('EP_TECDOC_PLUGIN', __FILE__);
define('EP_TECDOC_DIR', __DIR__);
define('EP_TECDOC_URL', rtrim(plugin_dir_url(EP_TECDOC_PLUGIN), '/'));

require_once __DIR__ . '/includes/product.php';
require_once __DIR__ . '/includes/rewrite.php';
require_once __DIR__ . '/includes/search.php';

require_once __DIR__ . '/includes/class-term-custom-fields.php';
new Tecdoc_Term_Custom_Fields();
require_once __DIR__ . '/includes/class-woocommerce-overrides.php';
new wooCommerceOverrides();

function __ignore()
{
    __('Chosen Vehicle', 'ep-tecdoc');
    __('Vehicle Change', 'ep-tecdoc');
    __('Car parts for', 'ep-tecdoc');
}

add_action('plugins_loaded', function() {
    load_plugin_textdomain('ep-tecdoc', false, basename(__DIR__) . '/languages');
});

add_filter('plugin_locale', function($locale, $domain) {

    if ('ep-tecdoc' === $domain && preg_match('/^de_/', $locale)) {
        return 'de';
    }

    return $locale;
}, 10, 2);

/**
 * Inicijalizacija.
 */
add_action('init', function() {
	// Proizvodi
	add_filter('posts_pre_query', 'ep_tecdoc_product_cat_query', 5, 2);
	add_action('the_posts', 'ep_tecdoc_product_get_posts', 10, 2);
	// Slike proizvoda
//	add_filter('get_post_metadata', 'ep_tecdoc_product_metadata', 10, 3);
//	add_filter('wp_get_attachment_image_src', 'ep_tecdoc_image_src', 10, 2);

	$services = ep_services();

	if ($services->has('TecDocProductProvider')) {
		$services->get('TecDocProductProvider');
	}
});

add_filter('body_class', function(array $classes) {
    $services = ep_services();
    /** @var \Ep\TecDoc\TecDocService $tecdoc */
    $tecdoc = $services->get('TecDoc');

    if ($tecdoc->getSelectedVehicle()) {
        $classes[] = 'has-selected-vehicle';
    }

    return $classes;
});

add_filter('ep/config/providers', function(array $providers) {
	$providers[] = \Ep\TecDoc\AnotherConfigProvider::class;
	return $providers;
});

/**
 * Vraća TecDoc artikl za proizvod.
 *
 * @param $productId
 *
 * @return array
 */
function ep_tecdoc_article($productId)
{
	$services = ep_services();
	/** @var \Psr\Cache\CacheItemPoolInterface $cache */
	$cache = $services->get('cache.tecdoc');

	$cacheKey = sprintf('articles.product.%d', $productId);
    /** @noinspection PhpUnhandledExceptionInspection */
    $item = $cache->getItem($cacheKey);

	if (!$item->isHit()) {
		/** @var WP_Post[] $posts */
		global $posts;

		if (is_array($posts)) {
			foreach ($posts as $post) {
				if ($post->ID === $productId && property_exists($post, 'tecdocArticle')) {
					return $post->tecdocArticle;
				}
			}
		}

		$articleKey = get_post_meta($productId, '_tecDoc_key', true);
		if (!$articleKey) return null;

		$tecdoc = ep_tecdoc_service();
		$articleId = $tecdoc->getArticleId($articleKey);
		if (!$articleId) return null;

		$articles = $tecdoc->getArticlesByIds([$articleId]);

		if (count($articles) > 0) {
			$article = $articles[0];
			$fullArticles = $tecdoc->getArticlesByGenericIds([$article['genericArticleId']]);

			if (count($fullArticles) > 0) {
				foreach ($fullArticles as $fullArticle) {
					if ($fullArticle['id'] === $article['id']) {
						$article = $fullArticle;
						break;
					}
				}
			}

			$item->set($article);
			$cache->save($item);
		}
	}

	return $item->get();
}

/**
 * @return \Ep\TecDoc\TecDocService
 */
function ep_tecdoc_service()
{
	$services = ep_services();
	return $services->get('TecDoc');
}