<?php
namespace Ep\TecDoc;

use Ep\Cache\AbstractCacheFactory;
use Ep\Http\AbstractHttpClientFactory;
use Zend\ServiceManager\AbstractFactory\ReflectionBasedAbstractFactory;
use Zend\Stdlib\ArrayUtils;

/**
 * Class ConfigProvider
 *
 * @package Ep\TecDoc
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-webshop
 */
class AnotherConfigProvider
{
	public function __invoke()
	{
        return $this->getConfig();
	}

	public function getTecDocSettings()
    {
        $settings = [];

        if (function_exists('get_option')) {
            $settings = ArrayUtils::merge($settings, get_option('ep_tecdoc', []));
        }

        if (is_string($settings['featuredManufacturerIds'])) {
            $settings['featuredManufacturerIds'] = array_map('intval', explode(';', $settings['featuredManufacturerIds']));
        }

        if (is_string($settings['excludedManufacturerIds'])) {
            $settings['excludedManufacturerIds'] = array_map('intval', explode(';', $settings['excludedManufacturerIds']));
        }

        return $settings;
    }

	public function getConfig()
    {
        return [
            'dependencies' => $this->getDependencies(),

            'wordpress' => [
                'metadata_providers' => [
                    'TecDocProductProvider',
                ],
            ],

            'caches' => [
                'cache.tecdoc' => [
                    'adapter' => defined('WP_DEBUG') && WP_DEBUG ? 'null' : 'filesystem',
                ],
            ],

            'http_clients' => [
                'http.tecdoc' => [
                    'cache' => 'cache.tecdoc',
                    'cache_ttl' => 3600,
                    'base_uri' => TecDocService::SERVICE_URI,
                    'timeout' => 2,
                    'headers' => [
                        'Content-Type' => 'application/json',
                    ],
                ],
            ],
        ];
    }

	public function getDependencies()
	{
		return [
			'aliases' => [
				'TecDoc' => TecDocService::class,
				'TecDocProductProvider' => ProductProvider::class,
			],
			'factories' => [
				TecDocService::class => TecDocServiceFactory::class,
                ProductProvider::class => ReflectionBasedAbstractFactory::class,

                'cache.tecdoc' => AbstractCacheFactory::class,
                'http.tecdoc' => AbstractHttpClientFactory::class,
			],
		];
	}
}